==> boo_0.5.6.1701.orig.tar.gz: boo-0.5.6.1701/src/Boo.Lang.Compiler/Ast/AttributeCollection.cs <==
﻿#region license
// Copyright (c) 2004, Rodrigo B. de Oliveira (rbo@acm.org)
// All rights reserved.
// 
// Redistribution and use in source and binary forms, with or without modification,
// are permitted provided that the following conditions are met:
// 
//     * Redistributions of source code must retain the above copyright notice,
//     this list of conditions and the following disclaimer.
//     * Redistributions in binary form must reproduce the above copyright notice,
//     this list of conditions and the following disclaimer in the documentation
//     and/or other materials provided with the distribution.
//     * Neither the name of Rodrigo B. de Oliveira nor the names of its
//     contributors may be used to endorse or promote products derived from this
//     software without specific prior written permission.
// 
// THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" AND
// ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
// WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
// DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER OR CONTRIBUTORS BE LIABLE
// FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
// DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
// SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER
// CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
// OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF
// THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
#endregion

using System;
using System.Collections;

namespace Boo.Lang.Compiler.Ast
{
	public class AttributeCollection : Boo.Lang.Compiler.Ast.Impl.AttributeCollectionImpl
	{
		public AttributeCollection()
		{
		}
		
		public AttributeCollection(Boo.Lang.Compiler.Ast.Node parent) : base(parent)
		{
		}
		
		public bool Contains(string attributeName)
		{
			foreach (Boo.Lang.Compiler.Ast.Attribute attribute in this)
			{
				if (attributeName == attribute.Name)
				{
					return true;
				}
			}
			return false;
		}
		
		public Boo.Lang.Compiler.Ast.Attribute[] Get(string attributeName)
		{
			ArrayList attributes = new ArrayList();
			foreach (Boo.Lang.Compiler.Ast.Attribute attribute in this)
			{
				if (0 == string.Compare(attributeName, attribute.Name, true))
				{
					attributes.Add(attribute);
				}
			}
			return (Boo.Lang.Compiler.Ast.Attribute[])attributes.ToArray(typeof(Boo.Lang.Compiler.Ast.Attribute));
		}
	}
}

==> boo_0.7.0.1921.orig.tar.gz: boo-0.7.0.1921/src/Boo.Lang.Compiler/Ast/AttributeCollection.cs <==
﻿#region license
// Copyright (c) 2004, Rodrigo B. de Oliveira (rbo@acm.org)
// All rights reserved.
// 
// Redistribution and use in source and binary forms, with or without modification,
// are permitted provided that the following conditions are met:
// 
//     * Redistributions of source code must retain the above copyright notice,
//     this list of conditions and the following disclaimer.
//     * Redistributions in binary form must reproduce the above copyright notice,
//     this list of conditions and the following disclaimer in the documentation
//     and/or other materials provided with the distribution.
//     * Neither the name of Rodrigo B. de Oliveira nor the names of its
//     contributors may be used to endorse or promote products derived from this
//     software without specific prior written permission.
// 
// THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" AND
// ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
// WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
// DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER OR CONTRIBUTORS BE LIABLE
// FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
// DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
// SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER
// CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
// OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF
// THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
#endregion

using System;
using System.Collections;

namespace Boo.Lang.Compiler.Ast
{
	public class AttributeCollection : Boo.Lang.Compiler.Ast.Impl.AttributeCollectionImpl
	{
		public AttributeCollection()
		{
		}
		
		public AttributeCollection(Boo.Lang.Compiler.Ast.Node parent) : base(parent)
		{
		}

		internal AttributeCollection(Boo.Lang.Compiler.Ast.Node parent, Boo.Lang.List list) : base(parent, list)
		{
		}
		
		public bool Contains(string attributeName)
		{
			foreach (Boo.Lang.Compiler.Ast.Attribute attribute in this)
			{
				if (attributeName == attribute.Name)
				{
					return true;
				}
			}
			return false;
		}
		
		public Boo.Lang.Compiler.Ast.Attribute[] Get(string attributeName)
		{
			ArrayList attributes = new ArrayList();
			foreach (Boo.Lang.Compiler.Ast.Attribute attribute in this)
			{
				if (0 == string.Compare(attributeName, attribute.Name, true))
				{
					attributes.Add(attribute);
				}
			}
			return (Boo.Lang.Compiler.Ast.Attribute[])attributes.ToArray(typeof(Boo.Lang.Compiler.Ast.Attribute));
		}
	}
}
